#!/bin/bash

# This helper script will handle deploying opensearch cluster and creating an external service to route
# to the DB
set -e

source /scripts/utils.sh
source /scripts/terraform.sh

check_access ${appsNamespace} services
check_access ${appsNamespace} configmaps

terraform_init
export TF_X_CONCISE_DIFF=0
terraform_plan
unset TF_X_CONCISE_DIFF
terraform_apply
terraform_output

if [ ${awsDeployment} == "true" ]; then
  print_header "Checking for the opensearch endpoint"

  terraform_get endpoint opensearchClusterEndpoint

  arnConfigMapName=${namingPrefix}-arn
  terraform_get arn arnValue
  terraform_get domainId domainId
  terraform_get kibanaEndpoint kibanaEndpoint

  cat >/tmp/config.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${arnConfigMapName}
data:
  ARN: ${arnValue}
  domainId: ${domainId}
  endpoint: ${opensearchClusterEndpoint}
  kibanaEndpoint: ${kibanaEndpoint}
EOF

  run_cmd cat "/tmp/config.yaml"
  /scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/config.yaml
  /scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/config.yaml

  echo "Config map ${arnConfigMapName}"
  /scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${arnConfigMapName} -o yaml

  create_hostname_configmap ${namingPrefix}-endpoint ${appsNamespace} "--from-literal=endpoint=${opensearchClusterEndpoint}"
  create_hostname_configmap ${namingPrefix}-endpoint ${infraNamespace} "--from-literal=endpoint=${opensearchClusterEndpoint}"

fi

cprint "$0 done"
